# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Initial release of sentor-ml Python SDK

### Changed

### Deprecated

### Removed

### Fixed

### Security

## [1.3.0] - 2024-01-XX

### Added
- Initial release of sentor-ml Python SDK
- Support for sentiment analysis API
- Command-line interface

### Changed

### Fixed
